%global efivar_version 28-1
%global efibootmgr_version 13-1

%define lib_major	1

%define libname		%mklibname fwup %{lib_major}
%define develname	%mklibname fwup -d

Name:		fwupdate
Version:	12
Release:	%mkrel 2
Summary:	Tools to manage UEFI firmware updates
Group:		System/Boot and Init
License:	GPLv2+
URL:		https://github.com/rhboot/fwupdate
Source0:	https://github.com/rhboot/fwupdate/releases/download/%{version}/%{name}-%{version}.tar.bz2
Source1:	find-debuginfo-efi.sh
Patch1:		fwupdate-fix-pointer-sign.patch
Patch1001:	c2bd33d6f2c3353e36d08238db11587084ebc1b1.patch
BuildRequires:	pkgconfig(efivar) >= %{efivar_version}
BuildRequires:	pkgconfig(efivar)
BuildRequires:	pesign
BuildRequires:	elfutils
BuildRequires:	gnu-efi-devel
BuildRequires:	pkgconfig(popt)
BuildRequires:	git
BuildRequires:	gettext
BuildRequires:	systemd
%ifarch x86_64 %{ix86}
BuildRequires:	pkgconfig(libsmbios_c)
%endif
ExclusiveArch:	x86_64 %{ix86} aarch64

%ifarch x86_64
%global efiarch x64
%endif
%ifarch %{ix86}
%global efiarch ia32
%endif
%ifarch aarch64
%global efiarch aa64
%endif

# Figure out the right file path to use
%global efidir %(eval echo $(grep ^ID= /etc/os-release | sed -e 's/^ID=//' -e 's/rhel/redhat/'))

%global __os_install_post %{expand: \
  %__os_install_post \
  %{SOURCE1} \
  %{nil}}%{nil}

%description
fwupdate provides a simple command line interface to the UEFI firmware updates.

%package -n %{libname}
Summary:	Library to manage UEFI firmware updates
Group:		System/Libraries
Requires:	%{name}-efi = %{version}-%{release}
Obsoletes:	%{_lib}libfwup1 < 9-2

%description -n %{libname}
Library to allow for the simple manipulation of UEFI firmware updates.

%package -n %{develname}
Summary:	Development headers for libfwup
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Requires:	efivar-devel >= %{efivar_version}
Obsoletes:	%{_lib}libfwup-devel < 9-2

%description -n %{develname}
development headers required to use libfwup.

%package efi
Summary:	UEFI binaries used by libfwup
Group:		System/Boot and Init
Requires:	%{libname} = %{version}-%{release}

%description efi
UEFI binaries used by libfwup.

%package efi-debuginfo
Summary:	debuginfo for UEFI binaries used by libfwup
Group:		Development/Debug
Requires:	%{name}-efi = %{version}-%{release}
AutoReq:	0
AutoProv:	1

%description efi-debuginfo
debuginfo for UEFI binaries used by libfwup.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} $CFLAGS -Wsign-compare -Wno-missing-field-initializers -Wno-address-of-packed-member"
make OPT_FLAGS="$RPM_OPT_FLAGS" libdir=%{_libdir} bindir=%{_bindir} \
     EFIDIR=%{efidir} %{?_smp_mflags}
mv -v efi/fwup%{efiarch}.efi efi/fwup%{efiarch}.unsigned.efi
%pesign -s -i efi/fwup%{efiarch}.unsigned.efi -o efi/fwup%{efiarch}.efi

%install
%make_install EFIDIR=%{efidir}/ libdir=%{_libdir} \
       bindir=%{_bindir} mandir=%{_mandir} localedir=%{_datadir}/locale/ \
       includedir=%{_includedir} libexecdir=%{_libexecdir} \
       datadir=%{_datadir}
mkdir %{buildroot}/%{_datadir}/fwupdate/

%post -n %{libname}
%systemd_post fwupdate-cleanup.service

%preun -n %{libname}
%systemd_preun fwupdate-cleanup.service

%postun -n %{libname}
%systemd_postun_with_restart pesign.service

%files
%license COPYING
# %%doc README
%{_bindir}/fwupdate
%{_datadir}/locale/en/fwupdate.po
%{_mandir}/man1/*
%{_datadir}/bash-completion/completions/fwupdate

%files -n %{develname}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%files -n %{libname}
%{_libdir}/libfwup.so.%{lib_major}
%{_libdir}/libfwup.so.%{lib_major}.*
%{_datadir}/locale/en/libfwup.po
%{_unitdir}/fwupdate-cleanup.service
%attr(0755,root,root) %dir %{_datadir}/fwupdate/
%config(noreplace) %ghost %{_datadir}/fwupdate/done
%attr(0755,root,root) %dir %{_libexecdir}/fwupdate/
%{_libexecdir}/fwupdate/cleanup

%files efi
%attr(0700,root,root) %dir /boot/efi
%dir /boot/efi/EFI/%{efidir}/
%dir /boot/efi/EFI/%{efidir}/fw/
/boot/efi/EFI/%{efidir}/fwup%{efiarch}.efi

%files efi-debuginfo -f debugfiles-efi.list


%changelog
* Mon Mar 30 2020 ovitters <ovitters> 12-2.mga8
+ Revision: 1562378
- add patch for pointer-sign build error
- sync patch
- retab spec
- add patch for arm build
- new version 12
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Oct 20 2018 pterjan <pterjan> 9-5.mga7
+ Revision: 1322736
- Do not require shim which we don't have

* Sun Sep 23 2018 umeabot <umeabot> 9-4.mga7
+ Revision: 1297810
- Mageia 7 Mass Rebuild

* Sun Jul 15 2018 wally <wally> 9-3.mga7
+ Revision: 1243790
- adapt efi debuginfo fixes from Fedora
+ daviddavid <daviddavid>
- fix lib and devel pkg name
- do not mark manpage as doc
- add missing Group

* Mon Jul 17 2017 ovitters <ovitters> 9-1.mga7
+ Revision: 1124524
- new version 9
- update URL and source
- fix requires
- imported package fwupdate


* Fri Aug 19 2016 Peter Jones <pjones@redhat.com> - 8-1
- Update to fwupdate 8
- Fix some i686 build errors
- Be less stupid about SONAMEs so in the future we'll only have to rebuild
  dependent things on actual ABI changes.
- Only depend on libsmbios on x86, for now, because it hasn't been ported to
  Aarch64.

* Wed Aug 17 2016 Peter Jones <pjones@redhat.com> - 7-1
- Update to fwupdate 7
- Fix the fix for ae7b85
- fix one place where a second "rc" varibale is clobbering a result.

* Tue Aug 16 2016 Peter Jones <pjones@redhat.com> - 6-1
- Update to fwupdate 6
- lots of build fixes for newer compilers and such
- Use libsmbios on some systems to enable firmware updates (Mario Limonciello)
- Use the correct reset type from the QueryCapsuleInfo data
- Lots of fixes from auditing
- Use efivar's error reporting infrastructure

* Fri Aug 12 2016 Adam Williamson <awilliam@redhat.com> - 0.5-5
- backport a couple of commits to fix build against efivar 26

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 18 2015 Peter Jones <pjones@redhat.com> - 0.5-3
- Temporarily don't require shim on i?86 - we've never built it there, and
  libfwup knows how to handle it not being there just fine.

* Wed Nov 18 2015 Peter Jones <pjones@redhat.com> - 0.5-2
- Fix missing -libs Requires: due to editing error

* Wed Nov 18 2015 Peter Jones <pjones@redhat.com> - 0.5-1
- Rebase to 0.5
- Highlights in 0.5:
  - fwupdate.efi is called fwup$EFI_ARCH.efi now so weird platforms can have
    them coexist.  "Platform" here might mean "distro tools that care about
    multilib".  Anyway, it's needed to support things like baytrail.
  - Worked around shim command line bug where we need to treat LOAD_OPTIONS
    differently if we're invoked from the shell vs BDS
  - various debug features - SHIM_DEBUG and FWUPDATE_VERBOSE UEFI variables
    that'll let you get some debugging info some times
  - oh yeah, the actual debuginfo is useful
  - Automatically cleans up old instances on fresh OS installs
  - valgrind --leak-check=full on fwupdate doesn't show any errors at all
  - covscan shows only two things; one *really* doesn't matter, the other is
    because it doesn't understand our firmware variable data structure and
    can't work out that we have guaranteed the length of some data in a code
    path it isn't considering.
  - fwup_set_up_update() API improvements
  - killed fwup_sterror() and friends entirely
  - Should work on x64, ia32, and aarch64.

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 Peter Jones <pjones@redhat.com> - 0.4-1
- Update to 0.4
- Set DESTDIR so it's more consistently respected
- Always use upper case for Boot#### names.
- Create abbreviated device paths for our BootNext entry.
- Make subdir Makefiles get the version right.
- Fix ucs2len() to handle max=-1 correctly.
- Compare the right blobs when we're searching old boot entries.
- Fix .efi generation on non-x86 platforms.
- Use a relative path for fwupdate.efi when launched from shim.
- Show fewer debugging messages.
- Set BootNext when we find an old Boot#### variable as well.
- Add fwup_get_fw_type().

* Mon Jun 01 2015 Peter Jones <pjones@redhat.com> - 0.3-4
- Make abbreviated device paths work in the BootNext entry.
- Fix a ucs2 parsing bug.

* Mon Jun 01 2015 Peter Jones <pjones@redhat.com> - 0.3-3
- Always use abbreviated device paths for Boot#### entries.

* Mon Jun 01 2015 Peter Jones <pjones@redhat.com> - 0.3-2
- Fix boot entry naming.

* Thu May 28 2015 Peter Jones <pjones@redhat.com> - 0.3-1
- Here we go again.
